@@ -1407,6 +1407,9 @@ mobile platforms). ||
 certs by default. ||
 || nativeEvents || boolean || Whether the session is capable of generating \
 native events when simulating user input. ||
+|| proxy || proxy object || Details of any proxy to use. If no proxy is \
+specified, whatever the system's current or default state is used. The format \
+is specified under Proxy JSON Object. ||
 
 
 </dd>
@@ -1443,6 +1446,27 @@ seconds since midnight, January 1, 1970 UTC.^1^ ||
 ^1^ When returning Cookie objects, the server should only omit an optional \
 field if it is incapable of providing the information.</dd>
 
+<dt>
+=== Proxy JSON Object ===
+</dt>
+<dd>
+A JSON object describing a Proxy configuration.
+
+|| *Key* || *Type* || *Description* ||
+|| proxyType || string || (Required) The type of proxy being used. Possible \
+values are: *direct* - A direct connection - no proxy in use, *manual* - \
+Manual proxy settings configured, e.g. setting a proxy for HTTP, a proxy for \
+FTP, etc, *pac* - Proxy autoconfiguration from a URL), autodetect (proxy \
+autodetection, probably with WPAD, *system* - Use system settings ||
+|| proxyAutoconfigUrl || string || (Required if proxyType == pac, Ignored \
+otherwise) Specifies the URL to be used for proxy autoconfiguration. \
+Expected format example: http://hostname.com:1234/pacfile ||
+|| ftpProxy, httpProxy, sslProxy || string || (Optional, Ignored if proxyType \
+!= manual) Specifies the proxies to be used for FTP, HTTP and HTTPS requests \
+respectively. Behaviour is undefined if a request is made, where the proxy \
+for the particular protocol is undefined, if proxyType is manual. Expected \
+format example: hostname.com:1234 ||
+</dd>
 </dl>
 
 = Messages =
